Changelog
=========

.. Use the following to start a new version entry:

   |version| (unreleased)
   ----------------------

   - change message [author]

1.0 (2011-10-25)
----------------

- Using the multi-line configuration value indent style rather than one
  line with multiple values. [pumazi]

1.0b1 (2011-10-21)
------------------

- Write the ``bootstrap.py`` script to the build directory. [pumazi]
- Write out the ``base.cfg`` with the specified Plone version. [pumazi]
- Generalize the Plone major version configuration into a single template
  file. [pumazi]
- Added the ``--latest`` option to use the latest of whatever major/minor
  Plone version. [pumazi] 
- Added the ``--extend-with`` option to allow for additional configuration
  (e.g. sources.cfg, good-py, versions.cfg, etc.). [pumazi]
- Added the ``--distributions`` option to allow for the addition of eggs
  (a.k.a. Python distributions). [pumazi]

1.0a1 (2011-10-21)
------------------

- Initial release. [pumazi]
